.. _data:

Data
####

Tools for importing and exporting data.

Toy graphs
**********

.. autofunction:: sknetwork.data.house

.. autofunction:: sknetwork.data.bow_tie

.. autofunction:: sknetwork.data.karate_club

.. autofunction:: sknetwork.data.miserables

.. autofunction:: sknetwork.data.painters

.. autofunction:: sknetwork.data.star_wars

.. autofunction:: sknetwork.data.movie_actor

Models
******

.. autofunction:: sknetwork.data.linear_graph

.. autofunction:: sknetwork.data.linear_digraph

.. autofunction:: sknetwork.data.cyclic_graph

.. autofunction:: sknetwork.data.cyclic_digraph

.. autofunction:: sknetwork.data.grid

.. autofunction:: sknetwork.data.erdos_renyi

.. autofunction:: sknetwork.data.block_model

.. autofunction:: sknetwork.data.albert_barabasi

.. autofunction:: sknetwork.data.watts_strogatz

Load
****

You can find some datasets on NetRep_.

.. autofunction:: sknetwork.data.load_edge_list

.. autofunction:: sknetwork.data.load_adjacency_list

.. autofunction:: sknetwork.data.load_graphml

.. autofunction:: sknetwork.data.load_netset

.. autofunction:: sknetwork.data.load_konect

.. autofunction:: sknetwork.data.convert_edge_list

.. _NetRep: http://networkrepository.com/

Save
****

.. autofunction:: sknetwork.data.save

.. autofunction:: sknetwork.data.load

